@@ -29,15 +29,15 @@ ResultAssignerArchive = R6Class("ResultAssignerArchive",
     #' @param instance ([bbotk::OptimInstanceBatchSingleCrit] | [bbotk::OptimInstanceBatchMultiCrit])\cr
     #'   The [bbotk::OptimInstance] the final result should be assigned to.
     assign_result = function(instance) {
-      res = instance$archive$best()
-      xdt = res[, instance$search_space$ids(), with = FALSE]
+      xydt = instance$archive$best()
+      xdt = xydt[, instance$search_space$ids(), with = FALSE]
       if (inherits(instance, "OptimInstanceBatchMultiCrit")) {
-        ydt = res[, instance$archive$cols_y, with = FALSE]
-        instance$assign_result(xdt, ydt)
+        ydt = xydt[, instance$archive$cols_y, with = FALSE]
+        instance$assign_result(xdt, ydt, xydt = xydt)
       }
       else {
-        y = unlist(res[, instance$archive$cols_y, with = FALSE])
-        instance$assign_result(xdt, y)
+        y = unlist(xydt[, instance$archive$cols_y, with = FALSE])
+        instance$assign_result(xdt, y, xydt = xydt)
       }
     }
   ),
